# Changelog

## [0.1.4](https://github.com/agntcy/agp/compare/agp-mcp-v0.1.3...agp-mcp-v0.1.4) (2025-05-21)


### Features

* **agp-mcp:** use reliable fire and forget ([#275](https://github.com/agntcy/agp/issues/275)) ([e609e69](https://github.com/agntcy/agp/commit/e609e696a2f2e28bfebe1d88ee4bc2f48013a6cb))

## [0.1.3](https://github.com/agntcy/agp/compare/agp-mcp-v0.1.2...agp-mcp-v0.1.3) (2025-05-14)


### Bug Fixes

* **agp-mcp:** use fix version of mcp dependency ([#258](https://github.com/agntcy/agp/issues/258)) ([eeb5f71](https://github.com/agntcy/agp/commit/eeb5f71f17597ef9b21114b6d079980b499d7aed))

## [0.1.2](https://github.com/agntcy/agp/compare/agp-mcp-v0.1.1...agp-mcp-v0.1.2) (2025-05-14)


### Features

* **agp-mcp:** update to latest bindings version ([#255](https://github.com/agntcy/agp/issues/255)) ([a4792b0](https://github.com/agntcy/agp/commit/a4792b0a0d35cbbe533ac8e83162ff48a0a9da56))

## [0.1.1](https://github.com/agntcy/agp/compare/agp-mcp-v0.1.0...agp-mcp-v0.1.1) (2025-05-14)


### Features

* detect client disconnection in AGP transport ([#231](https://github.com/agntcy/agp/issues/231)) ([42d5765](https://github.com/agntcy/agp/commit/42d57657ef32dc5c28db11c9f994aa0548328dfc))
* release AGP-MCP proxy ([#198](https://github.com/agntcy/agp/issues/198)) ([e2b4056](https://github.com/agntcy/agp/commit/e2b40564da271e8bfa732e81a3ce41690b0e6663))
* release agp-mcp pypi package ([#225](https://github.com/agntcy/agp/issues/225)) ([238d683](https://github.com/agntcy/agp/commit/238d68300134dc6771191077b9b18525609bb7af))


### Bug Fixes

* **agp-mcp:** lint ([#235](https://github.com/agntcy/agp/issues/235)) ([9faa855](https://github.com/agntcy/agp/commit/9faa855580681711de571ca5260f0da98461b74b))

## [0.1.0](https://github.com/agntcy/agp/compare/agp-mcp-v0.1.0...agp-mcp-v0.1.0) (2025-05-07)


### Features

* release AGP-MCP proxy ([#198](https://github.com/agntcy/agp/issues/198)) ([e2b4056](https://github.com/agntcy/agp/commit/e2b40564da271e8bfa732e81a3ce41690b0e6663))
* release agp-mcp pypi package ([#225](https://github.com/agntcy/agp/issues/225)) ([238d683](https://github.com/agntcy/agp/commit/238d68300134dc6771191077b9b18525609bb7af))
